[![PyPI version](https://badge.fury.io/py/brainglobe.svg)](https://badge.fury.io/py/brainglobe)
[![Website](https://img.shields.io/website?up_message=online&url=https%3A%2F%2Fbrainglobe.info)](https://brainglobe.info)

[![Brainglobe logo](https://brainglobe.info/_static/brainglobe.png)](https://brainglobe.info)

# BrainGlobe

This package provides all [BrainGlobe](https://brainglobe.info) tools in one place, installable [in a single command](#installing-and-updating).
Installing this package will provide you with the complete suite of BrainGlobe tools, without needing to worry about dependency resolution.
A complete list of the tools provided by this package [is provided on our website](https://brainglobe.info/documentation/index.html#individual-tool-documentation), and you can also read more about these tools there too.

If you are interested in running some of our analysis workflows, you might want to head over to [`brainglobe-workflows`](https://github.com/brainglobe/brainglobe-workflows) and install the analysis pipelines offered by that package too.

## Installing and Updating

See the [installation instructions over on the BrainGlobe website](https://brainglobe.info/documentation/index.html#installing-brainglobe) for full information.
But the TLDR is;

```bash
pip install brainglobe
```

and to update,

```bash
pip install brainglobe --update
```

## Seeking help or contributing
We are always happy to help users of our tools, and welcome any contributions. If you would like to get in contact with us for any reason, please see the [contact page of our website](https://brainglobe.info/contact.html).

---

# The Brainglobe Initiative

The BrainGlobe Initiative exists to facilitate the development of interoperable Python-based tools for computational neuroanatomy.

We have three aims:

- Develop specialist software for specific analysis and visualisation needs, such as [cellfinder](https://github.com/brainglobe/cellfinder) and [brainrender](https://github.com/brainglobe/brainrender).
- Develop core tools to facilitate others to build interoperable tools in Python, e.g. the [BrainGlobe Atlas API](https://github.com/brainglobe/bg-atlasapi).
- Build a community of neuroscientists and developers to share knowledge, build software and engage with the scientific, and open-source community (e.g. by organising hackathons).

## [Funding](https://brainglobe.info/funders.html#funders) Information

The BrainGlobe project is only possible due to grant funding and the generous support of host institutions, whose information [can be found on this website](https://brainglobe.info/funders.html#funders).
